# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: missionResponse.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='missionResponse.proto',
  package='colav',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15missionResponse.proto\x12\x05\x63olav\"\x90\x02\n\x0fMissionResponse\x12\x13\n\x0bmission_tag\x18\x01 \x02(\t\x12\x1f\n\x17mission_start_timestamp\x18\x02 \x02(\t\x12\x44\n\x10mission_response\x18\x03 \x02(\x0e\x32*.colav.MissionResponse.MissionResponseEnum\x12 \n\x18mission_response_details\x18\x04 \x02(\t\"_\n\x13MissionResponseEnum\x12\n\n\x06UNKOWN\x10\x00\x12\x14\n\x10MISSION_STARTING\x10\x01\x12\x11\n\rMISSION_ERROR\x10\x02\x12\x13\n\x0fMISSION_INVALID\x10\x03'
)



_MISSIONRESPONSE_MISSIONRESPONSEENUM = _descriptor.EnumDescriptor(
  name='MissionResponseEnum',
  full_name='colav.MissionResponse.MissionResponseEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_STARTING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_INVALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=210,
  serialized_end=305,
)
_sym_db.RegisterEnumDescriptor(_MISSIONRESPONSE_MISSIONRESPONSEENUM)


_MISSIONRESPONSE = _descriptor.Descriptor(
  name='MissionResponse',
  full_name='colav.MissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_tag', full_name='colav.MissionResponse.mission_tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_start_timestamp', full_name='colav.MissionResponse.mission_start_timestamp', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_response', full_name='colav.MissionResponse.mission_response', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_response_details', full_name='colav.MissionResponse.mission_response_details', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MISSIONRESPONSE_MISSIONRESPONSEENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=305,
)

_MISSIONRESPONSE.fields_by_name['mission_response'].enum_type = _MISSIONRESPONSE_MISSIONRESPONSEENUM
_MISSIONRESPONSE_MISSIONRESPONSEENUM.containing_type = _MISSIONRESPONSE
DESCRIPTOR.message_types_by_name['MissionResponse'] = _MISSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionResponse = _reflection.GeneratedProtocolMessageType('MissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MISSIONRESPONSE,
  '__module__' : 'missionResponse_pb2'
  # @@protoc_insertion_point(class_scope:colav.MissionResponse)
  })
_sym_db.RegisterMessage(MissionResponse)


# @@protoc_insertion_point(module_scope)
