# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: obstaclesUpdate.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='obstaclesUpdate.proto',
  package='colav',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15obstaclesUpdate.proto\x12\x05\x63olav\"\xd0\x08\n\x0fObstaclesUpdate\x12\x13\n\x0bmission_tag\x18\x01 \x02(\t\x12\x41\n\x11\x64ynamic_obstacles\x18\x02 \x03(\x0b\x32&.colav.ObstaclesUpdate.DynamicObstacle\x12?\n\x10static_obstacles\x18\x03 \x03(\x0b\x32%.colav.ObstaclesUpdate.StaticObstacle\x12\x11\n\ttimestamp\x18\x04 \x02(\t\x12\x10\n\x08timestep\x18\x05 \x02(\t\x1aY\n\nObstacleID\x12\x0b\n\x03tag\x18\x01 \x02(\t\x12>\n\x04type\x18\x02 \x02(\x0e\x32#.colav.ObstaclesUpdate.ObstacleType:\x0bUNSPECIFIED\x1a\xe4\x01\n\x04Pose\x12\x36\n\x08position\x18\x01 \x02(\x0b\x32$.colav.ObstaclesUpdate.Pose.Position\x12<\n\x0borientation\x18\x02 \x02(\x0b\x32\'.colav.ObstaclesUpdate.Pose.Orientation\x1a+\n\x08Position\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x1a\x39\n\x0bOrientation\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x12\t\n\x01w\x18\x04 \x02(\x02\x1aV\n\x05State\x12)\n\x04pose\x18\x01 \x02(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12\x10\n\x08velocity\x18\x02 \x02(\x02\x12\x10\n\x08yaw_rate\x18\x03 \x02(\x02\x1a\\\n\x08Geometry\x12\x19\n\x11\x61\x63\x63\x65ptance_radius\x18\x01 \x02(\x02\x12\x35\n\x10polyshape_points\x18\x02 \x03(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x1a\xa0\x01\n\x0f\x44ynamicObstacle\x12-\n\x02id\x18\x01 \x02(\x0b\x32!.colav.ObstaclesUpdate.ObstacleID\x12+\n\x05state\x18\x02 \x02(\x0b\x32\x1c.colav.ObstaclesUpdate.State\x12\x31\n\x08geometry\x18\x03 \x02(\x0b\x32\x1f.colav.ObstaclesUpdate.Geometry\x1a\x9d\x01\n\x0eStaticObstacle\x12-\n\x02id\x18\x01 \x02(\x0b\x32!.colav.ObstaclesUpdate.ObstacleID\x12)\n\x04pose\x18\x02 \x02(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12\x31\n\x08geometry\x18\x03 \x02(\x0b\x32\x1f.colav.ObstaclesUpdate.Geometry\"D\n\x0cObstacleType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06VESSEL\x10\x01\x12\r\n\tLAND_MASS\x10\x02\x12\x08\n\x04\x42UOY\x10\x03'
)



_OBSTACLESUPDATE_OBSTACLETYPE = _descriptor.EnumDescriptor(
  name='ObstacleType',
  full_name='colav.ObstaclesUpdate.ObstacleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VESSEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAND_MASS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUOY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1069,
  serialized_end=1137,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLESUPDATE_OBSTACLETYPE)


_OBSTACLESUPDATE_OBSTACLEID = _descriptor.Descriptor(
  name='ObstacleID',
  full_name='colav.ObstaclesUpdate.ObstacleID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.ObstaclesUpdate.ObstacleID.tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.ObstaclesUpdate.ObstacleID.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=331,
)

_OBSTACLESUPDATE_POSE_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='colav.ObstaclesUpdate.Pose.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.ObstaclesUpdate.Pose.Position.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.ObstaclesUpdate.Pose.Position.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.ObstaclesUpdate.Pose.Position.z', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=503,
)

_OBSTACLESUPDATE_POSE_ORIENTATION = _descriptor.Descriptor(
  name='Orientation',
  full_name='colav.ObstaclesUpdate.Pose.Orientation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.ObstaclesUpdate.Pose.Orientation.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.ObstaclesUpdate.Pose.Orientation.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.ObstaclesUpdate.Pose.Orientation.z', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='w', full_name='colav.ObstaclesUpdate.Pose.Orientation.w', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=562,
)

_OBSTACLESUPDATE_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='colav.ObstaclesUpdate.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='colav.ObstaclesUpdate.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='colav.ObstaclesUpdate.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBSTACLESUPDATE_POSE_POSITION, _OBSTACLESUPDATE_POSE_ORIENTATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=562,
)

_OBSTACLESUPDATE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='colav.ObstaclesUpdate.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='colav.ObstaclesUpdate.State.pose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='colav.ObstaclesUpdate.State.velocity', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='colav.ObstaclesUpdate.State.yaw_rate', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=650,
)

_OBSTACLESUPDATE_GEOMETRY = _descriptor.Descriptor(
  name='Geometry',
  full_name='colav.ObstaclesUpdate.Geometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='acceptance_radius', full_name='colav.ObstaclesUpdate.Geometry.acceptance_radius', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polyshape_points', full_name='colav.ObstaclesUpdate.Geometry.polyshape_points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=744,
)

_OBSTACLESUPDATE_DYNAMICOBSTACLE = _descriptor.Descriptor(
  name='DynamicObstacle',
  full_name='colav.ObstaclesUpdate.DynamicObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colav.ObstaclesUpdate.DynamicObstacle.id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='colav.ObstaclesUpdate.DynamicObstacle.state', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='colav.ObstaclesUpdate.DynamicObstacle.geometry', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=907,
)

_OBSTACLESUPDATE_STATICOBSTACLE = _descriptor.Descriptor(
  name='StaticObstacle',
  full_name='colav.ObstaclesUpdate.StaticObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colav.ObstaclesUpdate.StaticObstacle.id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='colav.ObstaclesUpdate.StaticObstacle.pose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='colav.ObstaclesUpdate.StaticObstacle.geometry', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=1067,
)

_OBSTACLESUPDATE = _descriptor.Descriptor(
  name='ObstaclesUpdate',
  full_name='colav.ObstaclesUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_tag', full_name='colav.ObstaclesUpdate.mission_tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_obstacles', full_name='colav.ObstaclesUpdate.dynamic_obstacles', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_obstacles', full_name='colav.ObstaclesUpdate.static_obstacles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='colav.ObstaclesUpdate.timestamp', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestep', full_name='colav.ObstaclesUpdate.timestep', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBSTACLESUPDATE_OBSTACLEID, _OBSTACLESUPDATE_POSE, _OBSTACLESUPDATE_STATE, _OBSTACLESUPDATE_GEOMETRY, _OBSTACLESUPDATE_DYNAMICOBSTACLE, _OBSTACLESUPDATE_STATICOBSTACLE, ],
  enum_types=[
    _OBSTACLESUPDATE_OBSTACLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=1137,
)

_OBSTACLESUPDATE_OBSTACLEID.fields_by_name['type'].enum_type = _OBSTACLESUPDATE_OBSTACLETYPE
_OBSTACLESUPDATE_OBSTACLEID.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_POSE_POSITION.containing_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_POSE_ORIENTATION.containing_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_POSE.fields_by_name['position'].message_type = _OBSTACLESUPDATE_POSE_POSITION
_OBSTACLESUPDATE_POSE.fields_by_name['orientation'].message_type = _OBSTACLESUPDATE_POSE_ORIENTATION
_OBSTACLESUPDATE_POSE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_STATE.fields_by_name['pose'].message_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_STATE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_GEOMETRY.fields_by_name['polyshape_points'].message_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_GEOMETRY.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_DYNAMICOBSTACLE.fields_by_name['id'].message_type = _OBSTACLESUPDATE_OBSTACLEID
_OBSTACLESUPDATE_DYNAMICOBSTACLE.fields_by_name['state'].message_type = _OBSTACLESUPDATE_STATE
_OBSTACLESUPDATE_DYNAMICOBSTACLE.fields_by_name['geometry'].message_type = _OBSTACLESUPDATE_GEOMETRY
_OBSTACLESUPDATE_DYNAMICOBSTACLE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_STATICOBSTACLE.fields_by_name['id'].message_type = _OBSTACLESUPDATE_OBSTACLEID
_OBSTACLESUPDATE_STATICOBSTACLE.fields_by_name['pose'].message_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_STATICOBSTACLE.fields_by_name['geometry'].message_type = _OBSTACLESUPDATE_GEOMETRY
_OBSTACLESUPDATE_STATICOBSTACLE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE.fields_by_name['dynamic_obstacles'].message_type = _OBSTACLESUPDATE_DYNAMICOBSTACLE
_OBSTACLESUPDATE.fields_by_name['static_obstacles'].message_type = _OBSTACLESUPDATE_STATICOBSTACLE
_OBSTACLESUPDATE_OBSTACLETYPE.containing_type = _OBSTACLESUPDATE
DESCRIPTOR.message_types_by_name['ObstaclesUpdate'] = _OBSTACLESUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObstaclesUpdate = _reflection.GeneratedProtocolMessageType('ObstaclesUpdate', (_message.Message,), {

  'ObstacleID' : _reflection.GeneratedProtocolMessageType('ObstacleID', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_OBSTACLEID,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.ObstacleID)
    })
  ,

  'Pose' : _reflection.GeneratedProtocolMessageType('Pose', (_message.Message,), {

    'Position' : _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), {
      'DESCRIPTOR' : _OBSTACLESUPDATE_POSE_POSITION,
      '__module__' : 'obstaclesUpdate_pb2'
      # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Pose.Position)
      })
    ,

    'Orientation' : _reflection.GeneratedProtocolMessageType('Orientation', (_message.Message,), {
      'DESCRIPTOR' : _OBSTACLESUPDATE_POSE_ORIENTATION,
      '__module__' : 'obstaclesUpdate_pb2'
      # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Pose.Orientation)
      })
    ,
    'DESCRIPTOR' : _OBSTACLESUPDATE_POSE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Pose)
    })
  ,

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_STATE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.State)
    })
  ,

  'Geometry' : _reflection.GeneratedProtocolMessageType('Geometry', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_GEOMETRY,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Geometry)
    })
  ,

  'DynamicObstacle' : _reflection.GeneratedProtocolMessageType('DynamicObstacle', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_DYNAMICOBSTACLE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.DynamicObstacle)
    })
  ,

  'StaticObstacle' : _reflection.GeneratedProtocolMessageType('StaticObstacle', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_STATICOBSTACLE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.StaticObstacle)
    })
  ,
  'DESCRIPTOR' : _OBSTACLESUPDATE,
  '__module__' : 'obstaclesUpdate_pb2'
  # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate)
  })
_sym_db.RegisterMessage(ObstaclesUpdate)
_sym_db.RegisterMessage(ObstaclesUpdate.ObstacleID)
_sym_db.RegisterMessage(ObstaclesUpdate.Pose)
_sym_db.RegisterMessage(ObstaclesUpdate.Pose.Position)
_sym_db.RegisterMessage(ObstaclesUpdate.Pose.Orientation)
_sym_db.RegisterMessage(ObstaclesUpdate.State)
_sym_db.RegisterMessage(ObstaclesUpdate.Geometry)
_sym_db.RegisterMessage(ObstaclesUpdate.DynamicObstacle)
_sym_db.RegisterMessage(ObstaclesUpdate.StaticObstacle)


# @@protoc_insertion_point(module_scope)
