# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: missionRequest.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='missionRequest.proto',
  package='colav',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14missionRequest.proto\x12\x05\x63olav\"\xf6\x06\n\x0eMissionRequest\x12\x0b\n\x03tag\x18\x01 \x02(\t\x12\x1f\n\x17mission_start_timestamp\x18\x02 \x02(\t\x12,\n\x06vessel\x18\x03 \x02(\x0b\x32\x1c.colav.MissionRequest.Vessel\x12:\n\x15mission_init_position\x18\x04 \x02(\x0b\x32\x1b.colav.MissionRequest.Point\x12:\n\x15mission_goal_position\x18\x05 \x02(\x0b\x32\x1b.colav.MissionRequest.Point\x12&\n\x1emission_goal_acceptance_radius\x18\x06 \x02(\x02\x1a(\n\x05Point\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1a\xbd\x04\n\x06Vessel\x12\x0b\n\x03tag\x18\x01 \x02(\t\x12\x42\n\x04type\x18\x02 \x02(\x0e\x32\'.colav.MissionRequest.Vessel.VesselType:\x0bUNSPECIFIED\x12J\n\x12vessel_constraints\x18\x03 \x02(\x0b\x32..colav.MissionRequest.Vessel.VesselConstraints\x12\x44\n\x0fvessel_geometry\x18\x04 \x02(\x0b\x32+.colav.MissionRequest.Vessel.VesselGeometry\x1a\xb3\x01\n\x11VesselConstraints\x12\x18\n\x10max_acceleration\x18\x03 \x02(\x02\x12\x18\n\x10max_deceleration\x18\x04 \x02(\x02\x12\x14\n\x0cmax_velocity\x18\x05 \x02(\x02\x12\x14\n\x0cmin_velocity\x18\x06 \x02(\x02\x12\x14\n\x0cmax_yaw_rate\x18\x07 \x02(\x02\x1a(\n\x05Point\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x1a\x61\n\x0eVesselGeometry\x12\x18\n\x10safety_threshold\x18\x01 \x01(\x02\x12\x35\n\x10polyshape_points\x18\x02 \x03(\x0b\x32\x1b.colav.MissionRequest.Point\"7\n\nVesselType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tHYDROFOIL\x10\x01\x12\t\n\x05OTHER\x10\x02'
)



_MISSIONREQUEST_VESSEL_VESSELTYPE = _descriptor.EnumDescriptor(
  name='VesselType',
  full_name='colav.MissionRequest.Vessel.VesselType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HYDROFOIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=863,
  serialized_end=918,
)
_sym_db.RegisterEnumDescriptor(_MISSIONREQUEST_VESSEL_VESSELTYPE)


_MISSIONREQUEST_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='colav.MissionRequest.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.MissionRequest.Point.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.MissionRequest.Point.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.MissionRequest.Point.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=342,
)

_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='colav.MissionRequest.Vessel.VesselConstraints.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.MissionRequest.Vessel.VesselConstraints.Point.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.MissionRequest.Vessel.VesselConstraints.Point.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.MissionRequest.Vessel.VesselConstraints.Point.z', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=762,
)

_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS = _descriptor.Descriptor(
  name='VesselConstraints',
  full_name='colav.MissionRequest.Vessel.VesselConstraints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_acceleration', index=0,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_deceleration', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_deceleration', index=1,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_velocity', index=2,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_velocity', full_name='colav.MissionRequest.Vessel.VesselConstraints.min_velocity', index=3,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_yaw_rate', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_yaw_rate', index=4,
      number=7, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS_POINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=762,
)

_MISSIONREQUEST_VESSEL_VESSELGEOMETRY = _descriptor.Descriptor(
  name='VesselGeometry',
  full_name='colav.MissionRequest.Vessel.VesselGeometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='safety_threshold', full_name='colav.MissionRequest.Vessel.VesselGeometry.safety_threshold', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polyshape_points', full_name='colav.MissionRequest.Vessel.VesselGeometry.polyshape_points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=764,
  serialized_end=861,
)

_MISSIONREQUEST_VESSEL = _descriptor.Descriptor(
  name='Vessel',
  full_name='colav.MissionRequest.Vessel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionRequest.Vessel.tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.MissionRequest.Vessel.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel_constraints', full_name='colav.MissionRequest.Vessel.vessel_constraints', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel_geometry', full_name='colav.MissionRequest.Vessel.vessel_geometry', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS, _MISSIONREQUEST_VESSEL_VESSELGEOMETRY, ],
  enum_types=[
    _MISSIONREQUEST_VESSEL_VESSELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=918,
)

_MISSIONREQUEST = _descriptor.Descriptor(
  name='MissionRequest',
  full_name='colav.MissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionRequest.tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_start_timestamp', full_name='colav.MissionRequest.mission_start_timestamp', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel', full_name='colav.MissionRequest.vessel', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_init_position', full_name='colav.MissionRequest.mission_init_position', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_goal_position', full_name='colav.MissionRequest.mission_goal_position', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_goal_acceptance_radius', full_name='colav.MissionRequest.mission_goal_acceptance_radius', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_POINT, _MISSIONREQUEST_VESSEL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=918,
)

_MISSIONREQUEST_POINT.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS_POINT.containing_type = _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS
_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_VESSEL_VESSELGEOMETRY.fields_by_name['polyshape_points'].message_type = _MISSIONREQUEST_POINT
_MISSIONREQUEST_VESSEL_VESSELGEOMETRY.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_VESSEL.fields_by_name['type'].enum_type = _MISSIONREQUEST_VESSEL_VESSELTYPE
_MISSIONREQUEST_VESSEL.fields_by_name['vessel_constraints'].message_type = _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS
_MISSIONREQUEST_VESSEL.fields_by_name['vessel_geometry'].message_type = _MISSIONREQUEST_VESSEL_VESSELGEOMETRY
_MISSIONREQUEST_VESSEL.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_VESSEL_VESSELTYPE.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST.fields_by_name['vessel'].message_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST.fields_by_name['mission_init_position'].message_type = _MISSIONREQUEST_POINT
_MISSIONREQUEST.fields_by_name['mission_goal_position'].message_type = _MISSIONREQUEST_POINT
DESCRIPTOR.message_types_by_name['MissionRequest'] = _MISSIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionRequest = _reflection.GeneratedProtocolMessageType('MissionRequest', (_message.Message,), {

  'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONREQUEST_POINT,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Point)
    })
  ,

  'Vessel' : _reflection.GeneratedProtocolMessageType('Vessel', (_message.Message,), {

    'VesselConstraints' : _reflection.GeneratedProtocolMessageType('VesselConstraints', (_message.Message,), {

      'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
        'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS_POINT,
        '__module__' : 'missionRequest_pb2'
        # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselConstraints.Point)
        })
      ,
      'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS,
      '__module__' : 'missionRequest_pb2'
      # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselConstraints)
      })
    ,

    'VesselGeometry' : _reflection.GeneratedProtocolMessageType('VesselGeometry', (_message.Message,), {
      'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELGEOMETRY,
      '__module__' : 'missionRequest_pb2'
      # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselGeometry)
      })
    ,
    'DESCRIPTOR' : _MISSIONREQUEST_VESSEL,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel)
    })
  ,
  'DESCRIPTOR' : _MISSIONREQUEST,
  '__module__' : 'missionRequest_pb2'
  # @@protoc_insertion_point(class_scope:colav.MissionRequest)
  })
_sym_db.RegisterMessage(MissionRequest)
_sym_db.RegisterMessage(MissionRequest.Point)
_sym_db.RegisterMessage(MissionRequest.Vessel)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselConstraints)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselConstraints.Point)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselGeometry)


# @@protoc_insertion_point(module_scope)
